DROP TABLE IF EXISTS movie CASCADE;

CREATE TABLE movie (
    movie_id integer PRIMARY KEY,
    title text NOT NULL,
    year integer NOT NULL,
    rating integer NOT NULL DEFAULT 0,
    UNIQUE ( title, year )
); 

-- Vlastním film "movie_id"
-- s názvem "title"
-- vytvořený roku "year",
-- kterému dávám "rating" hvězdiček.

INSERT INTO movie VALUES 
     ( 1, 'The Matrix', 1999, 2 ), 
     ( 2, 'Dracula', 1992, 4 ),
     ( 3, 'Dracula', 1931, 1 );

TABLE movie;


-- { title, year, rating } je nadklíč child. Můžeme vynechat DISTINCT:

SELECT title, year, rating FROM movie;

-- Vytvoříme virtuální relační proměnnou, 
-- která nebude obsahovat id:

DROP VIEW IF EXISTS movie_public CASCADE;

CREATE VIEW movie_public AS 
SELECT title, year, rating FROM movie;

-- Vlastním film s názvem "title"
-- vydaný v roce "year".
TABLE movie_public;

-- Změna hodnocení filmu The Matrix:

UPDATE movie_public 
SET    rating = 3 
WHERE  title = 'The Matrix';

TABLE movie_public;

-- Změna se provedla v relační proměnné movie:

TABLE movie;

-- Odebrání filmu Dracula z roku 1931:

DELETE FROM movie_public 
WHERE  title = 'Dracula'
AND    year = 1931;

TABLE movie_public;

-- Změna se opět provede v movie:

TABLE movie;

-- Nový film nelze přidat:

INSERT INTO movie_public VALUES 
  ( 'The Dark Knigh', 2008, 3 );

-- Nevíme, jaký jaké by měl mít movie_id.

-- Vytvoříme nový pohled na filmy bez hodnocení:
DROP VIEW IF EXISTS movie_without_rating CASCADE;

CREATE VIEW movie_without_rating AS 
SELECT movie_id, title, year FROM movie;

-- Do proměnné movie_without_rating už nový film přidat lze:
INSERT INTO movie_without_rating VALUES 
  ( 4, 'The Dark Knigh', 2008 );

TABLE movie_without_rating;

-- Do sloupce rating se vloží výchozí hodnota 0:

TABLE movie;
